==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AReferenceExpression.h <==
// public final class soot.jimple.parser.node.AReferenceExpression

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dfb8d0332612266e soot_jimple_parser_node_AReferenceExpression
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 17bf07e10ea3d87a soot_jimple_parser_node_PExpression

// header file dependencies
// @dep_header soot_jimple_parser_node_PExpression

#include "soot/jimple/parser/node/PExpression.h"

#ifndef _JC_soot_jimple_parser_node_AReferenceExpression_H_
#define _JC_soot_jimple_parser_node_AReferenceExpression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PReference$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AReferenceExpression$sub_refs	_jc_soot_jimple_parser_node_AReferenceExpression$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AReferenceExpression$sub_nonrefs	_jc_soot_jimple_parser_node_AReferenceExpression$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AReferenceExpression$refs	_jc_soot_jimple_parser_node_AReferenceExpression$refs;
typedef struct _jc_soot_jimple_parser_node_AReferenceExpression$nonrefs	_jc_soot_jimple_parser_node_AReferenceExpression$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AReferenceExpression$object	_jc_soot_jimple_parser_node_AReferenceExpression$object;

typedef const struct _jc_soot_jimple_parser_node_AReferenceExpression$vmethods	_jc_soot_jimple_parser_node_AReferenceExpression$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AReferenceExpression$vtable	_jc_soot_jimple_parser_node_AReferenceExpression$vtable;
typedef const struct _jc_soot_jimple_parser_node_AReferenceExpression$vtype	_jc_soot_jimple_parser_node_AReferenceExpression$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *);
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$_init$a6b928f349663da0(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_PReference$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AReferenceExpression$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *);
extern struct _jc_soot_jimple_parser_node_PReference$object *_jc_soot_jimple_parser_node_AReferenceExpression$method$getReference$731cb4a1297ac6a1(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *);
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$setReference$6a8a8e4fb98b5aa4(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_PReference$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AReferenceExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$getReference$731cb4a1297ac6a1;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$setReference$6a8a8e4fb98b5aa4;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AReferenceExpression$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *);
	struct _jc_soot_jimple_parser_node_PReference$object	*(*getReference$731cb4a1297ac6a1)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setReference$6a8a8e4fb98b5aa4)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_PReference$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AReferenceExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PExpression$vmethods	soot_jimple_parser_node_PExpression;
	_jc_soot_jimple_parser_node_AReferenceExpression$vmethods	soot_jimple_parser_node_AReferenceExpression;
};

// Vtype
struct _jc_soot_jimple_parser_node_AReferenceExpression$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AReferenceExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AReferenceExpression$sub_refs {
	struct _jc_soot_jimple_parser_node_PReference$object	*__5freference__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AReferenceExpression$refs {
    _jc_soot_jimple_parser_node_AReferenceExpression$sub_refs	soot_jimple_parser_node_AReferenceExpression;
    _jc_soot_jimple_parser_node_PExpression$sub_refs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AReferenceExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AReferenceExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PExpression$sub_nonrefs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_AReferenceExpression$sub_nonrefs	soot_jimple_parser_node_AReferenceExpression;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AReferenceExpression$object {
	_jc_soot_jimple_parser_node_AReferenceExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AReferenceExpression$vtype	*vtype;
	_jc_soot_jimple_parser_node_AReferenceExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AReferenceExpression$vtype _jc_soot_jimple_parser_node_AReferenceExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AReferenceExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AReferenceExpression$class_object;

#endif	/* _JC_soot_jimple_parser_node_AReferenceExpression_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AReferenceExpression.h <==
// public final class soot.jimple.parser.node.AReferenceExpression

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dfb8d0332612266e soot_jimple_parser_node_AReferenceExpression
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 17bf07e10ea3d87a soot_jimple_parser_node_PExpression

// header file dependencies
// @dep_header soot_jimple_parser_node_PExpression

#include "soot/jimple/parser/node/PExpression.h"

#ifndef _JC_soot_jimple_parser_node_AReferenceExpression_H_
#define _JC_soot_jimple_parser_node_AReferenceExpression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PReference$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AReferenceExpression$sub_refs	_jc_soot_jimple_parser_node_AReferenceExpression$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AReferenceExpression$sub_nonrefs	_jc_soot_jimple_parser_node_AReferenceExpression$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AReferenceExpression$refs	_jc_soot_jimple_parser_node_AReferenceExpression$refs;
typedef struct _jc_soot_jimple_parser_node_AReferenceExpression$nonrefs	_jc_soot_jimple_parser_node_AReferenceExpression$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AReferenceExpression$object	_jc_soot_jimple_parser_node_AReferenceExpression$object;

typedef const struct _jc_soot_jimple_parser_node_AReferenceExpression$vmethods	_jc_soot_jimple_parser_node_AReferenceExpression$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AReferenceExpression$vtable	_jc_soot_jimple_parser_node_AReferenceExpression$vtable;
typedef const struct _jc_soot_jimple_parser_node_AReferenceExpression$vtype	_jc_soot_jimple_parser_node_AReferenceExpression$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$_init$a6b928f349663da0(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_PReference$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AReferenceExpression$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PReference$object *_jc_soot_jimple_parser_node_AReferenceExpression$method$getReference$731cb4a1297ac6a1(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AReferenceExpression$method$setReference$6a8a8e4fb98b5aa4(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_PReference$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AReferenceExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$getReference$731cb4a1297ac6a1;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$setReference$6a8a8e4fb98b5aa4;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AReferenceExpression$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PReference$object	*(*getReference$731cb4a1297ac6a1)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setReference$6a8a8e4fb98b5aa4)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *, struct _jc_soot_jimple_parser_node_PReference$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceExpression$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AReferenceExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PExpression$vmethods	soot_jimple_parser_node_PExpression;
	_jc_soot_jimple_parser_node_AReferenceExpression$vmethods	soot_jimple_parser_node_AReferenceExpression;
};

// Vtype
struct _jc_soot_jimple_parser_node_AReferenceExpression$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AReferenceExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AReferenceExpression$sub_refs {
	struct _jc_soot_jimple_parser_node_PReference$object	*__5freference__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AReferenceExpression$refs {
    _jc_soot_jimple_parser_node_AReferenceExpression$sub_refs	soot_jimple_parser_node_AReferenceExpression;
    _jc_soot_jimple_parser_node_PExpression$sub_refs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AReferenceExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AReferenceExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PExpression$sub_nonrefs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_AReferenceExpression$sub_nonrefs	soot_jimple_parser_node_AReferenceExpression;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AReferenceExpression$object {
	_jc_soot_jimple_parser_node_AReferenceExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AReferenceExpression$vtype	*vtype;
	_jc_soot_jimple_parser_node_AReferenceExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AReferenceExpression$vtype _jc_soot_jimple_parser_node_AReferenceExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AReferenceExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AReferenceExpression$class_object;

#endif	/* _JC_soot_jimple_parser_node_AReferenceExpression_H_ */
